==> yaml_collection_03_12_2025-17_32.zip: app/snippets/code-header.php <==
<!DOCTYPE html> 
<html lang="">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta name="description" content="<?php echo $site->getHtml("site_description"); ?>">
        <meta name="keywords" content="<?php echo $site->getHtml("site_keywords"); ?>">
        <title><?php echo $site->getHtml("site_titre"); ?></title>
        <link rel="stylesheet" href="<?= URL ?>app/css/sfw.css">
        <link rel="stylesheet" href="<?= URL ?>app/css/quill.snow.css">
        <link rel="stylesheet" href="<?= URL ?>app/css/basics.css">
        <?php
    // charger les css du theme
              $l=glob(THEMES.THEME."/*.css");
              foreach($l as $css){
                  writehtmlcode($css);    
              }
        ?>
        <link rel="stylesheet" href="<?= URL ?>app/css/players.css">

        <link rel="apple-touch-icon" sizes="180x180" href="<?= URL.getThemeFile("favicons/apple-touch-icon.png") ?>">
        <link rel="icon" type="image/png" sizes="32x32" href="<?= URL.getThemeFile("favicons/favicon-32x32.png") ?>">
        <link rel="icon" type="image/png" sizes="16x16" href="<?= URL.getThemeFile("favicons/favicon-16x16.png") ?>">
        <link rel="icon" type="image/x-icon" href="<?= URL.getThemeFile("favicons/favicon.svg") ?>">

        <?php 
    // charger les css custom
    $l=glob(CONFIG."styles/*.css");
              foreach($l as $css){
                  writehtmlcode("contents/config/styles/".basename($css));    
              }
              // charger les css des modules
              foreach(MODULES['insert_css'] as $insert){
                  writehtmlcode($insert);
              }
        ?>
    </head>

    <body data-listingtype="<?= $theme->get('listingoption') ?>" <?php if($site->bool('tool_tri')){ ?>data-tri="id|asc" <?php } ?>data-viewertype="<?= $site->get('param_viewer') ?>" data-viewershow="hide" data-viewerloop="<?= $site->get('fw_loop') ?>" data-adminstatus="<?= (isadmin()) ? "true" : "false" ?>">
        <div id="main-frame">

==> yaml_collection_12_11_2025-10_04.zip: app/snippets/code-header.php <==
<!DOCTYPE html> 
<html lang="">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta name="description" content="<?php echo $site->getHtml("site_description"); ?>">
        <meta name="keywords" content="<?php echo $site->getHtml("site_keywords"); ?>">
        <title><?php echo $site->getHtml("site_titre"); ?></title>
        <link rel="stylesheet" href="<?= URL ?>app/css/sfw.css">
        <link rel="stylesheet" href="<?= URL ?>app/css/yseditor.css">
        <link rel="stylesheet" href="<?= URL ?>app/css/basics.css">
        <?php
    // charger les css du theme
              $l=glob(THEMES.THEME."/*.css");
              foreach($l as $css){
                  writehtmlcode($css);    
              }
        ?>
        <link rel="stylesheet" href="<?= URL ?>app/css/players.css">

        <link rel="apple-touch-icon" sizes="180x180" href="<?= URL.getThemeFile("favicons/apple-touch-icon.png") ?>">
        <link rel="icon" type="image/png" sizes="32x32" href="<?= URL.getThemeFile("favicons/favicon-32x32.png") ?>">
        <link rel="icon" type="image/png" sizes="16x16" href="<?= URL.getThemeFile("favicons/favicon-16x16.png") ?>">
        <link rel="icon" type="image/x-icon" href="<?= URL.getThemeFile("favicons/favicon.svg") ?>">

        <?php 
    // charger les css custom
    $l=glob(CONFIG."styles/*.css");
              foreach($l as $css){
                  writehtmlcode("contents/config/styles/".basename($css));    
              }
              // charger les css des modules
              foreach(MODULES['insert_css'] as $insert){
                  writehtmlcode($insert);
              }
        ?>
    </head>

    <body data-listingtype="<?= $theme->get('listingoption') ?>" <?php if($site->bool('tool_tri')){ ?>data-tri="id|asc" <?php } ?>data-viewertype="<?= $site->get('param_viewer') ?>" data-viewershow="hide" data-viewerloop="<?= $site->get('fw_loop') ?>">
        <div id="main-frame">
